@@ -8,7 +8,7 @@ from eth_utils import keccak
 from raiden_contracts.utils.type_aliases import ChainID, Locksroot
 
 # The last digit is supposed to be zero always. See `RELEASE.rst`.
-CONTRACTS_VERSION = "0.40.0"
+CONTRACTS_VERSION = "0.50.0"
 CORUSCANT_VERSION = "0.40.0"
 BESPIN_VERSION = "0.37.0"
 ALDERAAN_VERSION = "0.37.0"
@@ -29,11 +29,9 @@ CONTRACT_ONE_TO_N = "OneToN"
 CONTRACT_DEPOSIT = "Deposit"
 
 # Timeouts
-TEST_SETTLE_TIMEOUT_MIN = 5
-TEST_SETTLE_TIMEOUT_MAX = 100000
+TEST_SETTLE_TIMEOUT = 8 * 15  # Timeout in seconds
 
-DEPLOY_SETTLE_TIMEOUT_MIN = 500  # ~ 2 hours
-DEPLOY_SETTLE_TIMEOUT_MAX = 555428  # ~ 3 months
+DEPLOY_SETTLE_TIMEOUT = 1000 * 15  # ~ 4 hours
 
 # Temporary deposit limits for the Red Eyes release in WEI
 MAX_ETH_CHANNEL_PARTICIPANT = int(0.075 * 10**18)
@@ -71,13 +69,6 @@ class ChannelEvent(str, Enum):
     DEPRECATED = "DeprecationSwitch"
 
 
-class ChannelInfoIndex(IntEnum):
-    """Index for accessing fields in return information from TokenNetwork.getChannelInfo."""
-
-    SETTLE_BLOCK = 0
-    STATE = 1
-
-
 class ParticipantInfoIndex(IntEnum):
     """Index for accessing fields in return value of TokenNetwork.getChannelParticipantInfo."""
 
@@ -91,7 +82,7 @@ class ParticipantInfoIndex(IntEnum):
 
 
 class ChannelState(IntEnum):
-    """Meaning of values returned by TokenNetwork.getChannelInfo[ChannelInfoIndex.STATE]"""
+    """Meaning of values returned by TokenNetwork.getChannelState"""
 
     NONEXISTENT = 0
     OPENED = 1
@@ -150,6 +141,8 @@ ID_TO_CHAINNAME: Dict[ChainID, str] = {
     ChainID(5): "goerli",
     ChainID(42): "kovan",
     ChainID(627): "smoketest",
+    ChainID(42161): "arbitrum-one",
+    ChainID(421611): "rinkeby-arbitrum",
 }
 
 CHAINNAME_TO_ID: Dict[str, ChainID] = {name: id for id, name in ID_TO_CHAINNAME.items()}
