@@ -19,8 +19,7 @@ from web3.middleware import geth_poa_middleware
 from raiden_contracts.constants import (
     CONTRACT_CUSTOM_TOKEN,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
-    DEPLOY_SETTLE_TIMEOUT_MAX,
-    DEPLOY_SETTLE_TIMEOUT_MIN,
+    DEPLOY_SETTLE_TIMEOUT,
 )
 from raiden_contracts.contract_manager import DeployedContracts, contracts_deployed_path
 from raiden_contracts.deploy.contract_deployer import ContractDeployer
@@ -175,21 +174,11 @@ def check_version_dependent_parameters(
     help="The deployment file from which SecretRegistry should be reused",
 )
 @click.option(
-    "--settle-timeout-max",
+    "--settle-timeout",
     type=click.INT,
-    default=DEPLOY_SETTLE_TIMEOUT_MAX,
+    default=DEPLOY_SETTLE_TIMEOUT,
     help=(
-        "The maximum allowed settle timeout for the channels opened with this "
-        "set of smart contracts"
-    ),
-)
-@click.option(
-    "--settle-timeout-min",
-    type=click.INT,
-    default=DEPLOY_SETTLE_TIMEOUT_MIN,
-    help=(
-        "The minimum allowed settle timeout for the channels opened with this "
-        "set of smart contracts"
+        "The expected settle timeout for the channels opened with this " "set of smart contracts"
     ),
 )
 @click.pass_context
@@ -202,8 +191,7 @@ def raiden(
     gas_price: int,
     gas_limit: int,
     save_info: int,
-    settle_timeout_min: int,
-    settle_timeout_max: int,
+    settle_timeout: int,
     contracts_version: Optional[str],
     max_token_networks: Optional[int],
     secret_registry_from_deployment_file: Optional[str],
@@ -227,8 +215,7 @@ def raiden(
     deployed_contracts_info = deployer.deploy_raiden_contracts(
         max_num_of_token_networks=max_token_networks,
         reuse_secret_registry_from_deploy_file=secret_registry_from_deployment_path,
-        settle_timeout_min=settle_timeout_min,
-        settle_timeout_max=settle_timeout_max,
+        settle_timeout=settle_timeout,
     )
     deployed_contracts = {
         contract_name: info["address"]
@@ -260,6 +247,12 @@ def raiden(
     type=int,
     help="Maximum amount of tokens deposited in UserDeposit",
 )
+@click.option(
+    "--user-deposit-withdraw-timeout",
+    default=25 * 60,
+    type=int,
+    help="Time in seconds after which a withdraw is allowed",
+)
 @click.option(
     "--service-registry-controller",
     required=True,
@@ -328,6 +321,7 @@ def services(
     save_info: bool,
     contracts_version: Optional[str],
     user_deposit_whole_limit: int,
+    user_deposit_withdraw_timeout: int,
     service_registry_controller: HexAddress,
     initial_service_deposit_price: int,
     service_deposit_bump_numerator: int,
@@ -357,6 +351,7 @@ def services(
     deployed_contracts_info = deployer.deploy_service_contracts(
         token_address=token_address,
         user_deposit_whole_balance_limit=user_deposit_whole_limit,
+        user_deposit_withdraw_timeout=user_deposit_withdraw_timeout,
         service_registry_controller=service_registry_controller,
         initial_service_deposit_price=initial_service_deposit_price,
         service_deposit_bump_numerator=service_deposit_bump_numerator,
@@ -377,6 +372,7 @@ def services(
             deployed_contracts_info=deployed_contracts_info,
             token_address=token_address,
             user_deposit_whole_balance_limit=user_deposit_whole_limit,
+            user_deposit_withdraw_timeout=user_deposit_withdraw_timeout,
             token_network_registry_address=token_network_registry_address,
         )
     else:
@@ -384,6 +380,7 @@ def services(
             deployed_contracts_info=deployed_contracts_info,
             token_address=token_address,
             user_deposit_whole_balance_limit=user_deposit_whole_limit,
+            user_deposit_withdraw_timeout=user_deposit_withdraw_timeout,
             token_network_registry_address=token_network_registry_address,
         )
 
@@ -512,6 +509,7 @@ def register(
             "No TokenNetworkRegistry was specified. "
             "Add --token-network-registry-address <address>."
         )
+
     assert token_type in ctx.obj["deployed_contracts"]
     abi = deployer.contract_manager.get_contract_abi(CONTRACT_TOKEN_NETWORK_REGISTRY)
     token_network = deployer.register_token_network(
