@@ -17,10 +17,16 @@ def send_funds(ethereum_tester: EthereumTester, custom_token: Contract) -> Calla
     def f(target: str) -> None:
         assert is_address(target)
         ethereum_tester.send_transaction(
-            {"from": FAUCET_ADDRESS, "to": target, "gas": 21000, "value": 1 * int(units["ether"])}
+            {
+                "from": FAUCET_ADDRESS,
+                "to": target,
+                "gas": 21000,
+                "value": 1 * int(units["ether"]),
+            }
         )
         call_and_transact(
-            custom_token.functions.transfer(_to=target, _value=10000), {"from": FAUCET_ADDRESS}
+            custom_token.functions.transfer(_to=target, _value=10000),
+            {"from": FAUCET_ADDRESS},
         )
 
     return f
