@@ -5,10 +5,10 @@ from eth_tester.exceptions import TransactionFailed
 from hexbytes import HexBytes
 from web3 import Web3
 from web3.contract import Contract
-from web3.types import Wei
+from web3.types import BlockData, Wei
 
 from raiden_contracts.constants import (
-    TEST_SETTLE_TIMEOUT_MIN,
+    TEST_SETTLE_TIMEOUT,
     ChannelEvent,
     ChannelState,
     MessageTypeId,
@@ -23,20 +23,22 @@ from raiden_contracts.tests.utils import (
     call_and_transact,
     fake_bytes,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.events import check_channel_closed
 
 
 def test_close_nonexistent_channel(token_network: Contract, get_accounts: Callable) -> None:
-    """Test getChannelInfo and closeChannel on a not-yet opened channel"""
+    """Test getChannelState and closeChannel on a not-yet opened channel"""
     (A, B) = get_accounts(2)
     non_existent_channel_identifier = 1
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
+    state = token_network.functions.getChannelState(
         channel_identifier=non_existent_channel_identifier,
         participant1=A,
         participant2=B,
     ).call()
+    settle_block_number = token_network.functions.settleable_after(
+        non_existent_channel_identifier,
+    ).call()
     assert state == ChannelState.NONEXISTENT
     assert settle_block_number == 0
 
@@ -54,19 +56,20 @@ def test_close_nonexistent_channel(token_network: Contract, get_accounts: Callab
 
 
 def test_close_settled_channel_fail(
-    web3: Web3,
     token_network: Contract,
     create_channel: Callable,
     channel_deposit: Callable,
     get_accounts: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
-    """Test getChannelInfo and closeChannel on an already settled channel"""
+    """Test getChannelState and closeChannel on an already settled channel"""
     (A, B) = get_accounts(2)
-    channel_identifier = create_channel(A, B, TEST_SETTLE_TIMEOUT_MIN)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, 5, B)
 
-    (_, state) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
     assert state == ChannelState.OPENED
     closing_sig = create_close_signature_for_no_balance_proof(A, channel_identifier)
 
@@ -83,7 +86,9 @@ def test_close_settled_channel_fail(
         ),
         {"from": A},
     )
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier=channel_identifier,
@@ -99,9 +104,8 @@ def test_close_settled_channel_fail(
         {"from": A},
     )
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
     assert state == ChannelState.REMOVED
     assert settle_block_number == 0
 
@@ -321,7 +325,7 @@ def test_close_first_argument_is_for_partner_transfer(
     (A, B) = get_accounts(2)
 
     # Create channel
-    channel_identifier = create_channel(A, B, settle_timeout=TEST_SETTLE_TIMEOUT_MIN)[0]
+    channel_identifier = create_channel(A, B)[0]
 
     # Create balance proofs
     balance_proof = create_balance_proof(channel_identifier, B)
@@ -357,7 +361,7 @@ def test_close_first_participant_can_close(
     token_network: Contract,
     create_channel: Callable,
     get_accounts: Callable,
-    get_block: Callable[[HexBytes], int],
+    get_block: Callable[[HexBytes], BlockData],
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
     """Simplest successful closeChannel by the first participant"""
@@ -381,10 +385,10 @@ def test_close_first_participant_can_close(
         {"from": A},
     )
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, B, A
-    ).call()
-    assert settle_block_number == TEST_SETTLE_TIMEOUT_MIN + get_block(close_tx)
+    state = token_network.functions.getChannelState(channel_identifier, B, A).call()
+    settle_block_timestamp = token_network.functions.settleable_after(channel_identifier).call()
+    block_timestamp = get_block(close_tx).timestamp  # type: ignore
+    assert settle_block_timestamp == TEST_SETTLE_TIMEOUT + block_timestamp
     assert state == ChannelState.CLOSED
 
     (
@@ -458,7 +462,7 @@ def test_close_channel_state(
     accounts before/after a successful closeChannel call.
     """
     (A, B) = get_accounts(2)
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
+    settle_timeout = TEST_SETTLE_TIMEOUT
     vals_B = ChannelValues(
         deposit=20,
         transferred=5,
@@ -468,14 +472,13 @@ def test_close_channel_state(
     )
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, B, vals_B.deposit, A)
 
     # Check the state of the openned channel
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
-    assert settle_block_number == settle_timeout
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
+    assert settle_block_number == 0  # initialized only on channel close
     assert state == ChannelState.OPENED
 
     (
@@ -542,10 +545,9 @@ def test_close_channel_state(
     assert custom_token.functions.balanceOf(B).call() == pre_balance_B
     assert custom_token.functions.balanceOf(token_network.address).call() == pre_balance_contract
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
-    assert settle_block_number == settle_timeout + get_block(txn_hash)
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settle_block_timestamp = token_network.functions.settleable_after(channel_identifier).call()
+    assert settle_block_timestamp == settle_timeout + get_block(txn_hash).timestamp
     assert state == ChannelState.CLOSED
 
     (
@@ -619,13 +621,14 @@ def test_close_channel_event_no_offchain_transfers(
 
 
 def test_close_replay_reopened_channel(
-    web3: Web3,
     get_accounts: Callable,
     token_network: Contract,
     create_channel: Callable,
     channel_deposit: Callable,
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """The same balance proof cannot close another channel between the same participants"""
     (A, B) = get_accounts(2)
@@ -659,7 +662,9 @@ def test_close_replay_reopened_channel(
         ),
         {"from": A},
     )
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier=channel_identifier1,
