@@ -1,3 +1,4 @@
+import time
 from typing import Callable
 
 import pytest
@@ -8,9 +9,8 @@ from web3.exceptions import ValidationError
 from raiden_contracts.constants import EMPTY_ADDRESS, ChannelEvent
 from raiden_contracts.tests.utils import EMPTY_LOCKSROOT, call_and_transact
 from raiden_contracts.utils.events import check_channel_settled, check_withdraw_2
-from raiden_contracts.utils.type_aliases import BlockExpiration
 
-EXPIRATION = BlockExpiration(100)
+EXPIRATION = int(time.time()) + 100 * 15
 
 
 def test_cooperative_settle_channel_call(
