@@ -7,7 +7,7 @@ from web3 import Web3
 from web3.contract import Contract
 
 from raiden_contracts.constants import (
-    TEST_SETTLE_TIMEOUT_MIN,
+    TEST_SETTLE_TIMEOUT,
     ChannelEvent,
     ChannelState,
     MessageTypeId,
@@ -26,7 +26,6 @@ from raiden_contracts.tests.utils import (
     get_onchain_settlement_amounts,
     get_settlement_amounts,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.events import check_channel_settled
 from raiden_contracts.utils.pending_transfers import (
     get_pending_transfers_tree_with_generated_lists,
@@ -34,18 +33,18 @@ from raiden_contracts.utils.pending_transfers import (
 
 
 def test_settle_no_bp_success(
-    web3: Web3,
     custom_token: Contract,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """The simplest settlement without any balance proofs provided"""
     (A, B) = get_accounts(2)
     deposit_A = 10
     deposit_B = 6
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
     closing_sig = create_close_signature_for_no_balance_proof(A, channel_identifier)
 
@@ -67,7 +66,7 @@ def test_settle_no_bp_success(
     # Do not call updateNonClosingBalanceProof
 
     # Settlement window must be over before settling the channel
-    mine_blocks(web3, settle_timeout + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
 
     # Settling the channel should work with no balance proofs
     call_and_transact(
@@ -90,18 +89,18 @@ def test_settle_no_bp_success(
 
 
 def test_settle2_no_bp_success(
-    web3: Web3,
     custom_token: Contract,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """The simplest settlement, tested against the V2 ABI settle"""
     (A, B) = get_accounts(2)
     deposit_A = 10
     deposit_B = 6
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     channel_identifier = create_channel_and_deposit(A, B, deposit_A, deposit_B)
     closing_sig = create_close_signature_for_no_balance_proof(A, channel_identifier)
 
@@ -123,7 +122,7 @@ def test_settle2_no_bp_success(
     # Do not call updateNonClosingBalanceProof
 
     # Settlement window must be over before settling the channel
-    mine_blocks(web3, settle_timeout + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
 
     # Settling the channel should work with no balance proofs
     call_and_transact(
@@ -158,6 +157,8 @@ def test_settle_channel_state(
     withdraw_channel: Callable,
     close_and_update_channel: Callable,
     settle_state_tests: Callable,
+    get_block_timestamp: Callable,
+    time_travel: Callable,
 ) -> None:
     """settleChannel() with some balance proofs"""
     (A, B) = get_accounts(2)
@@ -192,7 +193,7 @@ def test_settle_channel_state(
     withdraw_channel(channel_identifier, B, vals_B.withdrawn, UINT256_MAX, A)
     close_and_update_channel(channel_identifier, A, vals_A, B, vals_B)
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     pre_balance_A = custom_token.functions.balanceOf(A).call()
     pre_balance_B = custom_token.functions.balanceOf(B).call()
@@ -226,7 +227,6 @@ def test_settle_channel_state(
 
 
 def test_settle_single_direct_transfer_for_closing_party(
-    web3: Web3,
     get_accounts: Callable,
     custom_token: Contract,
     token_network: Contract,
@@ -234,6 +234,8 @@ def test_settle_single_direct_transfer_for_closing_party(
     channel_deposit: Callable,
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Test settle of a channel with one direct transfer to the participant
     that called close.
@@ -243,7 +245,6 @@ def test_settle_single_direct_transfer_for_closing_party(
         ChannelValues(deposit=1, withdrawn=0, transferred=0),
         ChannelValues(deposit=10, withdrawn=0, transferred=5),
     )
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
 
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, vals_A.deposit, B)
@@ -274,7 +275,8 @@ def test_settle_single_direct_transfer_for_closing_party(
     pre_balance_B = custom_token.functions.balanceOf(B).call()
     pre_balance_contract = custom_token.functions.balanceOf(token_network.address).call()
 
-    mine_blocks(web3, settle_timeout + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier=channel_identifier,
@@ -305,7 +307,6 @@ def test_settle_single_direct_transfer_for_closing_party(
 
 
 def test_settle_single_direct_transfer_for_counterparty(
-    web3: Web3,
     get_accounts: Callable,
     custom_token: Contract,
     token_network: Contract,
@@ -314,6 +315,8 @@ def test_settle_single_direct_transfer_for_counterparty(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Test settle of a channel with one direct transfer to the participant
     that did not call close.
@@ -323,7 +326,6 @@ def test_settle_single_direct_transfer_for_counterparty(
         ChannelValues(deposit=10, withdrawn=0, transferred=5),
         ChannelValues(deposit=1, withdrawn=0, transferred=0),
     )
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
 
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, vals_A.deposit, B)
@@ -373,7 +375,8 @@ def test_settle_single_direct_transfer_for_counterparty(
     pre_balance_B = custom_token.functions.balanceOf(B).call()
     pre_balance_contract = custom_token.functions.balanceOf(token_network.address).call()
 
-    mine_blocks(web3, settle_timeout + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier=channel_identifier,
@@ -404,7 +407,6 @@ def test_settle_single_direct_transfer_for_counterparty(
 
 
 def test_settlement_with_unauthorized_token_transfer(
-    web3: Web3,
     get_accounts: Callable,
     custom_token: Contract,
     token_network: Contract,
@@ -412,6 +414,8 @@ def test_settlement_with_unauthorized_token_transfer(
     create_channel_and_deposit: Callable,
     withdraw_channel: Callable,
     close_and_update_channel: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """A participant transfers some tokens to the contract and so loses them"""
     externally_transferred_amount = 5
@@ -448,7 +452,7 @@ def test_settlement_with_unauthorized_token_transfer(
         pre_balance_contract + externally_transferred_amount
     )
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     # Compute expected settlement amounts
     settlement = get_settlement_amounts(vals_A, vals_B)
@@ -479,12 +483,13 @@ def test_settlement_with_unauthorized_token_transfer(
 
 
 def test_settle_wrong_state_fail(
-    web3: Web3,
     get_accounts: Callable,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_block: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """settleChannel() fails on OPENED state and on CLOSED state before the settlement block"""
     (A, B) = get_accounts(2)
@@ -492,11 +497,8 @@ def test_settle_wrong_state_fail(
     vals_B = ChannelValues(deposit=40)
     channel_identifier = create_channel_and_deposit(A, B, vals_A.deposit, vals_B.deposit)
 
-    (settle_timeout, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
     assert state == ChannelState.OPENED
-    assert settle_timeout == TEST_SETTLE_TIMEOUT_MIN
 
     with pytest.raises(TransactionFailed, match="TN/settle: channel not closed"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
@@ -516,25 +518,24 @@ def test_settle_wrong_state_fail(
         {"from": A},
     )
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settle_block_timeout = token_network.functions.settleable_after(channel_identifier).call()
     assert state == ChannelState.CLOSED
-    assert settle_block_number == TEST_SETTLE_TIMEOUT_MIN + get_block(txn_hash)
-    assert web3.eth.block_number < settle_block_number
+    assert settle_block_timeout == TEST_SETTLE_TIMEOUT + get_block(txn_hash).timestamp
+    assert get_block_timestamp() < settle_block_timeout
 
     with pytest.raises(TransactionFailed, match="TN/settle: settlement timeout"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
-    assert web3.eth.block_number > settle_block_number
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
+
+    assert get_block_timestamp() > settle_block_timeout
 
     # Channel is settled
     call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
     assert state == ChannelState.REMOVED
     assert settle_block_number == 0
 
@@ -546,6 +547,8 @@ def test_settle_wrong_balance_hash(
     create_channel_and_deposit: Callable,
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Calling settleChannel() with various wrong arguments and see failures"""
     (A, B) = get_accounts(2)
@@ -585,7 +588,7 @@ def test_settle_wrong_balance_hash(
 
     close_and_update_channel(channel_identifier, A, vals_A, B, vals_B)
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, B, vals_A, A, vals_B)
@@ -667,7 +670,6 @@ def test_settle_wrong_balance_hash(
 
 
 def test_settle_channel_event(
-    web3: Web3,
     get_accounts: Callable,
     token_network: Contract,
     create_channel: Callable,
@@ -675,12 +677,13 @@ def test_settle_channel_event(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
     event_handler: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """A successful settleChannel() call causes a SETTLED event"""
     ev_handler = event_handler(token_network)
     (A, B) = get_accounts(2)
     deposit_A = 10
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
 
     channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
@@ -717,7 +720,8 @@ def test_settle_channel_event(
         {"from": B},
     )
 
-    mine_blocks(web3, settle_timeout + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
+
     txn_hash = call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier=channel_identifier,
