@@ -5,7 +5,7 @@ from eth_tester.exceptions import TransactionFailed
 from web3 import Web3
 from web3.contract import Contract
 
-from raiden_contracts.constants import TEST_SETTLE_TIMEOUT_MIN, ChannelEvent, ParticipantInfoIndex
+from raiden_contracts.constants import TEST_SETTLE_TIMEOUT, ChannelEvent, ParticipantInfoIndex
 from raiden_contracts.tests.fixtures.channel import call_settle
 from raiden_contracts.tests.utils import (
     LOCKSROOT_OF_NO_LOCKS,
@@ -18,7 +18,6 @@ from raiden_contracts.tests.utils import (
     fake_bytes,
     get_unlocked_amount,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.events import check_channel_unlocked
 from raiden_contracts.utils.pending_transfers import (
     get_locked_amount,
@@ -64,6 +63,7 @@ def test_1_item_unlockable(
     get_accounts: Callable,
     token_network_test_utils: Contract,
     secret_registry_contract: Contract,
+    get_block_timestamp: Callable,
 ) -> None:
     """Test getHashRootAndUnlockedAmount() on a single item whose secret has been registered"""
     A = get_accounts(1)[0]
@@ -78,10 +78,10 @@ def test_1_item_unlockable(
         {"from": A},
     )
     assert (
-        secret_registry_contract.functions.getSecretRevealBlockHeight(
+        secret_registry_contract.functions.getSecretRevealBlockTime(
             pending_transfers_tree.unlockable[0][LockIndex.SECRETHASH]
         ).call()
-        == web3.eth.block_number
+        == get_block_timestamp()
     )
 
     (
@@ -101,6 +101,7 @@ def test_get_hash_length_fail(
     get_accounts: Callable,
     token_network_test_utils: Contract,
     secret_registry_contract: Contract,
+    get_block_timestamp: Callable,
 ) -> None:
     """Test getHashAndUnlockedAmount() on inputs of irregular lengths"""
     network_utils = token_network_test_utils
@@ -114,10 +115,10 @@ def test_get_hash_length_fail(
         {"from": A},
     )
     assert (
-        secret_registry_contract.functions.getSecretRevealBlockHeight(
+        secret_registry_contract.functions.getSecretRevealBlockTime(
             pending_transfers_tree.unlockable[0][LockIndex.SECRETHASH]
         ).call()
-        == web3.eth.block_number
+        == get_block_timestamp()
     )
 
     packed = pending_transfers_tree.packed_transfers
@@ -259,15 +260,18 @@ def test_lock_data_from_packed_locks(
     token_network_test_utils: Contract,
     secret_registry_contract: Contract,
     reveal_secrets: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Test getLockDataFromLockPublic() on various offsets"""
     network_utils = token_network_test_utils
+    max_lock_expiration = 100
     A = get_accounts(1)[0]
 
     unlockable_amounts = [3, 5]
     expired_amounts = [2, 8, 7]
     pending_transfers_tree = get_pending_transfers_tree(
-        web3, unlockable_amounts, expired_amounts, max_expiration_delta=5
+        web3, unlockable_amounts, expired_amounts, max_expiration_delta=max_lock_expiration
     )
     reveal_secrets(A, pending_transfers_tree.unlockable)
 
@@ -302,16 +306,17 @@ def test_lock_data_from_packed_locks(
     assert claimable_amount == claimable(4)
 
     # Register last secret after expiration
-    mine_blocks(web3, 5)
+    time_travel(get_block_timestamp() + max_lock_expiration + 1)
+
     last_lock = pending_transfers_tree.expired[-1]
     # expiration
-    assert web3.eth.block_number > last_lock[0]
+    assert get_block_timestamp() > last_lock[0]
     # register secret
     call_and_transact(secret_registry_contract.functions.registerSecret(last_lock[3]))
     # ensure registration was done
     assert (
-        secret_registry_contract.functions.getSecretRevealBlockHeight(last_lock[2]).call()
-        == web3.eth.block_number
+        secret_registry_contract.functions.getSecretRevealBlockTime(last_lock[2]).call()
+        == get_block_timestamp()
     )
 
     # Check that last secret is still regarded as expired
@@ -332,7 +337,7 @@ def test_unlock_wrong_locksroot(
 ) -> None:
     """Test unlocking with wrong pending locks"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     pending_transfers_tree_A = get_pending_transfers_tree(web3, [1, 3, 5], [], settle_timeout)
     pending_transfers_tree_A_fake = get_pending_transfers_tree(web3, [1, 3, 6], [], settle_timeout)
@@ -344,7 +349,6 @@ def test_unlock_wrong_locksroot(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
@@ -379,7 +383,7 @@ def test_channel_unlock_bigger_locked_amount(
     to the other party.
     """
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_A = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -397,7 +401,6 @@ def test_channel_unlock_bigger_locked_amount(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     pre_balance_A = custom_token.functions.balanceOf(A).call()
@@ -438,7 +441,7 @@ def test_channel_unlock_smaller_locked_amount(
     the participant receives less tokens. Stealing tokens from other channels
     is then prevented."""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_A = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -456,7 +459,6 @@ def test_channel_unlock_smaller_locked_amount(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     pre_balance_A = custom_token.functions.balanceOf(A).call()
@@ -493,7 +495,7 @@ def test_channel_unlock_bigger_unlocked_amount(
 ) -> None:
     """unlock() transfers not more than the locked amount for more expensive unlock() demands"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_A = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -511,7 +513,6 @@ def test_channel_unlock_bigger_unlocked_amount(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     pre_balance_A = custom_token.functions.balanceOf(A).call()
@@ -545,14 +546,13 @@ def test_channel_unlock_no_locked_amount_fail(
 ) -> None:
     """After settleChannel() is called with zero locked amount, unlock() calls fail"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
 
     # Mock pending transfers data
-    pending_transfers_tree_A = get_pending_transfers_tree(web3, [2, 5], [4], settle_timeout)
+    pending_transfers_tree_A = get_pending_transfers_tree(web3, [2, 5], [4], TEST_SETTLE_TIMEOUT)
     reveal_secrets(A, pending_transfers_tree_A.unlockable)
 
     channel_identifier = create_settled_channel(
-        A, 0, LOCKSROOT_OF_NO_LOCKS, B, 0, LOCKSROOT_OF_NO_LOCKS, settle_timeout
+        A, 0, LOCKSROOT_OF_NO_LOCKS, B, 0, LOCKSROOT_OF_NO_LOCKS
     )
 
     with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
@@ -572,22 +572,25 @@ def test_channel_unlock(
     get_accounts: Callable,
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """unlock() on pending transfers with unlockable and expired locks should
     split the locked amount accordingly, to both parties"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
 
     values_A = ChannelValues(deposit=20, transferred=5)
     values_B = ChannelValues(deposit=30, transferred=40)
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, values_A.deposit, B)
     channel_deposit(channel_identifier, B, values_B.deposit, A)
 
     # Mock pending transfers data
-    pending_transfers_tree = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
+    pending_transfers_tree = get_pending_transfers_tree(
+        web3, [1, 3, 5], [2, 4], TEST_SETTLE_TIMEOUT
+    )
     values_B.locksroot = pending_transfers_tree.hash_of_packed_transfers
     values_B.locked_amounts = LockedAmounts(
         claimable_locked=get_locked_amount(pending_transfers_tree.transfers)
@@ -599,7 +602,7 @@ def test_channel_unlock(
     close_and_update_channel(channel_identifier, A, values_A, B, values_B)
 
     # Settlement window must be over before settling the channel
-    mine_blocks(web3, settle_timeout)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     call_settle(token_network, channel_identifier, A, values_A, B, values_B)
 
@@ -640,7 +643,7 @@ def test_channel_settle_and_unlock(
 ) -> None:
     """Regular channel life-cycle: open -> settle -> unlock -> open -> settle -> unlock"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_1 = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -654,7 +657,6 @@ def test_channel_settle_and_unlock(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
     call_and_transact(
         token_network.functions.unlock(
@@ -700,7 +702,6 @@ def test_channel_settle_and_unlock(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     # Mock pending transfers data for a reopened channel
@@ -715,7 +716,6 @@ def test_channel_settle_and_unlock(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     # Both old and new unlocks should go through
@@ -742,17 +742,18 @@ def test_channel_unlock_registered_expired_lock_refunds(
     channel_deposit: Callable,
     get_accounts: Callable,
     close_and_update_channel: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """unlock() should refund tokens locked with secrets revealed after the expiration"""
     (A, B) = get_accounts(2)
-    max_lock_expiration = 3
-    settle_timeout = 8
+    max_lock_expiration = 100
 
     values_A = ChannelValues(deposit=20, transferred=5)
     values_B = ChannelValues(deposit=30, transferred=40)
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, values_A.deposit, B)
     channel_deposit(channel_identifier, B, values_B.deposit, A)
 
@@ -761,7 +762,7 @@ def test_channel_unlock_registered_expired_lock_refunds(
         web3,
         [1, 3, 5],
         [2, 4],
-        min_expiration_delta=max_lock_expiration - 2,
+        min_expiration_delta=max_lock_expiration - 50,
         max_expiration_delta=max_lock_expiration,
     )
     values_B.locksroot = pending_transfers_tree.hash_of_packed_transfers
@@ -770,18 +771,18 @@ def test_channel_unlock_registered_expired_lock_refunds(
     )
 
     # Locks expire
-    mine_blocks(web3, max_lock_expiration)
+    time_travel(get_block_timestamp() + max_lock_expiration + 1)
 
     # Secrets are revealed before settlement window, but after expiration
     for (_, _, secrethash, secret) in pending_transfers_tree.unlockable:
         call_and_transact(secret_registry_contract.functions.registerSecret(secret), {"from": A})
         assert (
-            secret_registry_contract.functions.getSecretRevealBlockHeight(secrethash).call()
-            == web3.eth.block_number
+            secret_registry_contract.functions.getSecretRevealBlockTime(secrethash).call()
+            == get_block_timestamp()
         )
 
     close_and_update_channel(channel_identifier, A, values_A, B, values_B)
-    mine_blocks(web3, settle_timeout)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     # settle channel
     call_settle(token_network, channel_identifier, A, values_A, B, values_B)
@@ -815,12 +816,15 @@ def test_channel_unlock_unregistered_locks(
     withdraw_channel: Callable,
     close_and_update_channel: Callable,
     custom_token: Contract,
+    get_block_timestamp: Callable,
+    time_travel: Callable,
 ) -> None:
     """unlock() should refund tokens locked by secrets not registered before settlement"""
     (A, B) = get_accounts(2)
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
 
-    pending_transfers_tree = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
+    pending_transfers_tree = get_pending_transfers_tree(
+        web3, [1, 3, 5], [2, 4], TEST_SETTLE_TIMEOUT
+    )
     locked_A = pending_transfers_tree.locked_amount
     (vals_A, vals_B) = (
         ChannelValues(
@@ -841,7 +845,7 @@ def test_channel_unlock_unregistered_locks(
     close_and_update_channel(channel_identifier, A, vals_A, B, vals_B)
 
     # Secret hasn't been registered before settlement timeout
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
     call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
     # Someone unlocks A's pending transfers - all tokens should be refunded
@@ -868,19 +872,22 @@ def test_channel_unlock_before_settlement_fails(
     get_accounts: Callable,
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
+    get_block_timestamp: Callable,
+    time_travel: Callable,
 ) -> None:
     """unlock() should not work before settlement"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
 
     values_A = ChannelValues(deposit=20, transferred=5)
     values_B = ChannelValues(deposit=30, transferred=40)
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
 
     # Mock pending transfers data
-    pending_transfers_tree = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
+    pending_transfers_tree = get_pending_transfers_tree(
+        web3, [1, 3, 5], [2, 4], TEST_SETTLE_TIMEOUT
+    )
     values_B.locksroot = pending_transfers_tree.hash_of_packed_transfers
     values_B.locked_amounts = LockedAmounts(
         claimable_locked=get_locked_amount(pending_transfers_tree.transfers)
@@ -913,7 +920,7 @@ def test_channel_unlock_before_settlement_fails(
         ).call()
 
     # Settlement window must be over before settling the channel
-    mine_blocks(web3, settle_timeout)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     # Unlock fails before settle is called
     with pytest.raises(TransactionFailed, match="TN/unlock: channel id still exists"):
@@ -952,7 +959,7 @@ def test_unlock_fails_with_partial_locks(
 ) -> None:
     """unlock() should fail when one lock is missing"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -966,7 +973,6 @@ def test_unlock_fails_with_partial_locks(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     # Unlock with one leave missing does not work
@@ -998,7 +1004,7 @@ def test_unlock_tampered_proof_fails(
 ) -> None:
     """unlock() should fail when the submitted proofs are tampered"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -1012,7 +1018,6 @@ def test_unlock_tampered_proof_fails(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     # Unlock with tampered locks does not work
@@ -1045,21 +1050,24 @@ def test_channel_unlock_both_participants(
     get_accounts: Callable,
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
+    get_block_timestamp: Callable,
+    time_travel: Callable,
 ) -> None:
     """A scenario where both parties get some of the pending transfers"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
 
     values_A = ChannelValues(deposit=100, transferred=5)
     values_B = ChannelValues(deposit=100, transferred=40)
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, values_A.deposit, B)
     channel_deposit(channel_identifier, B, values_B.deposit, A)
 
     # Mock pending transfers data for A
-    pending_transfers_tree_A = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
+    pending_transfers_tree_A = get_pending_transfers_tree(
+        web3, [1, 3, 5], [2, 4], TEST_SETTLE_TIMEOUT
+    )
     values_A.locksroot = pending_transfers_tree_A.hash_of_packed_transfers
     values_A.locked_amounts = LockedAmounts(
         claimable_locked=get_locked_amount(pending_transfers_tree_A.transfers)
@@ -1069,7 +1077,9 @@ def test_channel_unlock_both_participants(
     reveal_secrets(A, pending_transfers_tree_A.unlockable)
 
     # Mock pending transfers data for B
-    pending_transfers_tree_B = get_pending_transfers_tree(web3, [2, 4, 6], [5, 10], settle_timeout)
+    pending_transfers_tree_B = get_pending_transfers_tree(
+        web3, [2, 4, 6], [5, 10], TEST_SETTLE_TIMEOUT
+    )
     values_B.locksroot = pending_transfers_tree_B.hash_of_packed_transfers
     values_B.locked_amounts = LockedAmounts(
         claimable_locked=get_locked_amount(pending_transfers_tree_B.transfers)
@@ -1081,7 +1091,7 @@ def test_channel_unlock_both_participants(
     close_and_update_channel(channel_identifier, A, values_A, B, values_B)
 
     # Settle channel
-    mine_blocks(web3, settle_timeout)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     call_settle(token_network, channel_identifier, A, values_A, B, values_B)
 
@@ -1140,7 +1150,7 @@ def test_unlock_twice_fails(
 ) -> None:
     """The same unlock() call twice do not work"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_1 = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -1154,7 +1164,6 @@ def test_unlock_twice_fails(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
     call_and_transact(
         token_network.functions.unlock(
@@ -1175,7 +1184,7 @@ def test_unlock_no_locks(
 ) -> None:
     """unlock() should work on no pending locks"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree = get_pending_transfers_tree(
@@ -1193,7 +1202,6 @@ def test_unlock_no_locks(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
     call_and_transact(
         token_network.functions.unlock(
@@ -1218,22 +1226,23 @@ def test_channel_unlock_with_a_large_expiration(
     get_accounts: Callable,
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """unlock() should still work after a delayed settleChannel() call"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
 
     values_A = ChannelValues(deposit=20, transferred=5)
     values_B = ChannelValues(deposit=30, transferred=40)
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, values_A.deposit, B)
     channel_deposit(channel_identifier, B, values_B.deposit, A)
 
     # Mock pending transfers data with large expiration date
     pending_transfers_tree = get_pending_transfers_tree(
-        web3, [1, 3, 5], [2, 4], settle_timeout + 100
+        web3, [1, 3, 5], [2, 4], TEST_SETTLE_TIMEOUT + 100
     )
     values_B.locksroot = pending_transfers_tree.hash_of_packed_transfers
     values_B.locked_amounts = LockedAmounts(
@@ -1246,7 +1255,7 @@ def test_channel_unlock_with_a_large_expiration(
     close_and_update_channel(channel_identifier, A, values_A, B, values_B)
 
     # Settle channel after a "long" time
-    mine_blocks(web3, settle_timeout + 50)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 500)
 
     call_settle(token_network, channel_identifier, A, values_A, B, values_B)
 
@@ -1278,7 +1287,7 @@ def test_reverse_participants_unlock(
 ) -> None:
     """unlock() with wrong argument orders"""
     (A, B, C) = get_accounts(3)
-    settle_timeout = 12
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_A = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -1300,7 +1309,6 @@ def test_reverse_participants_unlock(
         B,
         pending_transfers_tree_B.locked_amount,
         pending_transfers_tree_B.hash_of_packed_transfers,
-        settle_timeout,
     )
 
     # A trying to unlock its own locksroot & locked amount MUST fail
@@ -1363,7 +1371,7 @@ def test_unlock_different_channel_same_participants_fail(
 ) -> None:
     """Try to confuse unlock() with two channels between the same participants"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
     # Mock pending transfers data
     pending_transfers_tree_1 = get_pending_transfers_tree(web3, [1, 3, 5], [2, 4], settle_timeout)
@@ -1375,7 +1383,6 @@ def test_unlock_different_channel_same_participants_fail(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     # The first channel is settled, so we create another one
@@ -1388,7 +1395,6 @@ def test_unlock_different_channel_same_participants_fail(
         B,
         0,
         LOCKSROOT_OF_NO_LOCKS,
-        settle_timeout,
     )
 
     with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
@@ -1424,22 +1430,23 @@ def test_unlock_channel_event(
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
     event_handler: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Successful unlock() should cause an UNLOCKED event"""
     (A, B) = get_accounts(2)
-    settle_timeout = 8
 
     values_A = ChannelValues(deposit=20, transferred=5)
     values_B = ChannelValues(deposit=30, transferred=40)
 
     # Create channel and deposit
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, values_A.deposit, B)
     channel_deposit(channel_identifier, B, values_B.deposit, A)
 
     # Mock pending transfers data
     pending_transfers_tree = get_pending_transfers_tree(
-        web3, [1, 3, 5], [2, 4], settle_timeout + 100
+        web3, [1, 3, 5], [2, 4], TEST_SETTLE_TIMEOUT + 100
     )
     values_B.locksroot = pending_transfers_tree.hash_of_packed_transfers
     values_B.locked_amounts = LockedAmounts(
@@ -1452,7 +1459,7 @@ def test_unlock_channel_event(
     close_and_update_channel(channel_identifier, A, values_A, B, values_B)
 
     # Settlement window must be over before settling the channel
-    mine_blocks(web3, settle_timeout)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     call_settle(token_network, channel_identifier, A, values_A, B, values_B)
 
