@@ -8,7 +8,7 @@ from web3.contract import Contract
 
 from raiden_contracts.constants import (
     EMPTY_ADDRESS,
-    TEST_SETTLE_TIMEOUT_MIN,
+    TEST_SETTLE_TIMEOUT,
     ChannelEvent,
     ChannelState,
     MessageTypeId,
@@ -21,7 +21,6 @@ from raiden_contracts.tests.utils import (
     call_and_transact,
     fake_bytes,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.events import check_transfer_updated
 
 
@@ -156,9 +155,8 @@ def test_update_nonexistent_fail(
     (A, B, C) = get_accounts(3)
     channel_identifier = 1
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
     assert settle_block_number == 0
     assert state == ChannelState.NONEXISTENT
 
@@ -201,10 +199,7 @@ def test_update_notclosed_fail(
         **balance_proof_A._asdict(),
     )
 
-    (settle_block_number, state) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
-    assert settle_block_number > 0
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
     assert state == ChannelState.OPENED
 
     with pytest.raises(TransactionFailed, match="TN/update: channel not closed"):
@@ -227,9 +222,8 @@ def test_update_wrong_nonce_fail(
     update_state_tests: Callable,
 ) -> None:
     (A, B, Delegate) = get_accounts(3)
-    settle_timeout = 6
     deposit_A = 20
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
     balance_proof_A = create_balance_proof(channel_identifier, A, 10, 0, 5, fake_bytes(32, "02"))
     balance_proof_B = create_balance_proof(channel_identifier, B, 5, 0, 3, fake_bytes(32, "02"))
@@ -309,7 +303,7 @@ def test_update_wrong_nonce_fail(
         balance_proof_A,
         B,
         balance_proof_B,
-        settle_timeout,
+        TEST_SETTLE_TIMEOUT,
         txn_hash1,
     )
 
@@ -406,9 +400,9 @@ def test_update_channel_state(
 ) -> None:
     """A successful updateNonClosingBalanceProof() call should not change token/ETH balances"""
     (A, B, Delegate) = get_accounts(3)
-    settle_timeout = 6
+    settle_timeout = TEST_SETTLE_TIMEOUT
     deposit_A = 20
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
     balance_proof_A = create_balance_proof(channel_identifier, A, 10, 0, 5, fake_bytes(32, "02"))
     balance_proof_B = create_balance_proof(channel_identifier, B, 5, 0, 3, fake_bytes(32, "02"))
@@ -538,13 +532,13 @@ def test_update_allowed_after_settlement_period(
     get_accounts: Callable,
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
-    web3: Web3,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """updateNonClosingBalanceProof can be called after the settlement period."""
     (A, B) = get_accounts(2)
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
     balance_proof_A = create_balance_proof(channel_identifier, A, 10, 0, 5, fake_bytes(32, "02"))
     balance_proof_B = create_balance_proof(channel_identifier, B, 5, 0, 3, fake_bytes(32, "02"))
@@ -566,7 +560,9 @@ def test_update_allowed_after_settlement_period(
         ),
         {"from": A},
     )
-    mine_blocks(web3, settle_timeout + 1)
+
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
+
     token_network.functions.updateNonClosingBalanceProof(
         channel_identifier,
         A,
@@ -586,9 +582,8 @@ def test_update_not_allowed_for_the_closing_address(
 ) -> None:
     """Closing address cannot call updateNonClosingBalanceProof."""
     (A, B, M) = get_accounts(3)
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
 
     # Some balance proof from B
@@ -662,9 +657,8 @@ def test_update_invalid_balance_proof_arguments(
 ) -> None:
     """updateNonClosingBalanceProof() should fail on balance proofs with various wrong params"""
     (A, B, C) = get_accounts(3)
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
 
     closing_sig = create_close_signature_for_no_balance_proof(A, channel_identifier)
@@ -900,9 +894,8 @@ def test_update_signature_on_invalid_arguments(
 ) -> None:
     """Call updateNonClosingBalanceProof with signature on invalid argument fails"""
     (A, B, C) = get_accounts(3)
-    settle_timeout = TEST_SETTLE_TIMEOUT_MIN
     deposit_A = 20
-    channel_identifier = create_channel(A, B, settle_timeout)[0]
+    channel_identifier = create_channel(A, B)[0]
     channel_deposit(channel_identifier, A, deposit_A, B)
     balance_proof = namedtuple(
         "balance_proof", ["balance_hash", "nonce", "additional_hash", "signature"]
@@ -1077,7 +1070,6 @@ def test_update_signature_on_invalid_arguments(
 
 
 def test_update_replay_reopened_channel(
-    web3: Web3,
     get_accounts: Callable,
     token_network: Contract,
     create_channel: Callable,
@@ -1085,6 +1077,8 @@ def test_update_replay_reopened_channel(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """updateNonClosingBalanceProof() should refuse a balance proof with a stale channel id"""
     (A, B) = get_accounts(2)
@@ -1135,7 +1129,8 @@ def test_update_replay_reopened_channel(
         {"from": A},
     )
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier1,
