@@ -26,8 +26,6 @@ from raiden_contracts.constants import (
     CONTRACT_SERVICE_REGISTRY,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     CONTRACT_USER_DEPOSIT,
-    DEPLOY_SETTLE_TIMEOUT_MAX,
-    DEPLOY_SETTLE_TIMEOUT_MIN,
     EMPTY_ADDRESS,
 )
 from raiden_contracts.contract_manager import DeployedContracts, contracts_precompiled_path
@@ -91,10 +89,7 @@ def deployer_0_37_0(web3: Web3) -> ContractDeployer:
 @pytest.fixture(scope="session")
 def deployed_raiden_info(deployer: ContractDeployer) -> DeployedContracts:
     return deployer.deploy_raiden_contracts(
-        max_num_of_token_networks=1,
-        reuse_secret_registry_from_deploy_file=None,
-        settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-        settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
+        max_num_of_token_networks=1, reuse_secret_registry_from_deploy_file=None
     )
 
 
@@ -102,10 +97,7 @@ def deployed_raiden_info(deployer: ContractDeployer) -> DeployedContracts:
 @pytest.fixture(scope="session")
 def deployed_raiden_info2(deployer: ContractDeployer) -> DeployedContracts:
     return deployer.deploy_raiden_contracts(
-        max_num_of_token_networks=1,
-        reuse_secret_registry_from_deploy_file=None,
-        settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-        settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
+        max_num_of_token_networks=1, reuse_secret_registry_from_deploy_file=None
     )
 
 
@@ -126,6 +118,7 @@ def token_address(deployer: ContractDeployer) -> HexAddress:
 
 
 DEPOSIT_LIMIT = TOKEN_SUPPLY // 2
+WITHDRAW_TIMEOUT = 25 * 60
 
 
 @pytest.mark.slow
@@ -138,6 +131,7 @@ def deployed_service_info(
     return deployer.deploy_service_contracts(
         token_address=token_address,
         user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
+        user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
         service_registry_controller=DEPLOYER_ADDRESS,
         initial_service_deposit_price=SERVICE_DEPOSIT // 2,
         service_deposit_bump_numerator=6,
@@ -161,6 +155,7 @@ def test_deploy_service_0_37_0(
         deployer_0_37_0.deploy_service_contracts(
             token_address=token_address,
             user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             service_registry_controller=DEPLOYER_ADDRESS,
             initial_service_deposit_price=SERVICE_DEPOSIT // 2,
             service_deposit_bump_numerator=6,
@@ -298,12 +293,7 @@ def test_deploy_script_raiden(
         wait=10,
     )
     with pytest.raises(ValidationError):
-        deployer.deploy_raiden_contracts(
-            1,
-            reuse_secret_registry_from_deploy_file=None,
-            settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-            settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
-        )
+        deployer.deploy_raiden_contracts(1, reuse_secret_registry_from_deploy_file=None)
 
 
 def test_deploy_raiden_reuse_secret_registry(
@@ -314,10 +304,7 @@ def test_deploy_raiden_reuse_secret_registry(
         previous_deployment_file.write(bytearray(json.dumps(deployed_raiden_info), "ascii"))
         previous_deployment_file.flush()
         new_deployment = deployer.deploy_raiden_contracts(
-            1,
-            reuse_secret_registry_from_deploy_file=Path(previous_deployment_file.name),
-            settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-            settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
+            1, reuse_secret_registry_from_deploy_file=Path(previous_deployment_file.name)
         )
         assert (
             new_deployment["contracts"][CONTRACT_SECRET_REGISTRY]
@@ -342,6 +329,7 @@ def test_deploy_services_reuse_service_registry(
         new_deployment = deployer.deploy_service_contracts(
             token_address=token_address,
             user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             service_registry_controller=DEPLOYER_ADDRESS,
             initial_service_deposit_price=SERVICE_DEPOSIT // 2,
             service_deposit_bump_numerator=6,
@@ -482,6 +470,7 @@ def test_deploy_script_service(
     deployer.verify_service_contracts_deployment_data(
         token_address=token_address,
         user_deposit_whole_balance_limit=deposit_limit,
+        user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
         deployed_contracts_info=deployed_service_contracts,
         token_network_registry_address=token_network_registry_contract.address,
     )
@@ -491,6 +480,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=EMPTY_ADDRESS,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_service_contracts,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -501,6 +491,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -511,6 +502,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -523,6 +515,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -535,6 +528,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -546,6 +540,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -558,6 +553,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -570,6 +566,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -585,6 +582,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -597,6 +595,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -609,6 +608,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -621,6 +621,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -631,6 +632,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -641,6 +643,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -651,6 +654,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -662,6 +666,7 @@ def test_deploy_script_service(
         deployer.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=deposit_limit,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             deployed_contracts_info=deployed_info_fail,
             token_network_registry_address=token_network_registry_contract.address,
         )
@@ -673,6 +678,7 @@ def test_deploy_script_service(
             deployer.verify_service_contracts_deployment_data(
                 token_address=token_address,
                 user_deposit_whole_balance_limit=deposit_limit,
+                user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
                 deployed_contracts_info=deployed_info_fail,
                 token_network_registry_address=token_network_registry_contract.address,
             )
@@ -759,12 +765,14 @@ def test_store_and_verify_services(
         token_address=token_address,
         deployed_contracts_info=deployed_contracts_info,
         user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
+        user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
         token_network_registry_address=token_network_registry_contract.address,
     )
     deployer.store_and_verify_deployment_info_services(
         token_address=token_address,
         deployed_contracts_info=deployed_contracts_info,
         user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
+        user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
         token_network_registry_address=token_network_registry_contract.address,
     )
 
@@ -830,7 +838,10 @@ def test_deploy_token_no_balance(privkey_file: IO) -> None:
             mock_deployer.assert_not_called()
 
 
-def test_deploy_token_with_balance(privkey_file: IO) -> None:
+@patch.object(ContractDeployer, "_adjust_chain_settings")
+def test_deploy_token_with_balance(
+    mock_adjust_chain_settings: MagicMock, privkey_file: IO
+) -> None:
     """Call deploy token command with a private key with some balance"""
     with patch.object(
         ContractDeployer,
@@ -842,6 +853,7 @@ def test_deploy_token_with_balance(privkey_file: IO) -> None:
             runner = CliRunner()
             result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
             assert result.exit_code == 0
+            mock_adjust_chain_settings.assert_called_once()
             mock_deployer.assert_called_once()
 
 
@@ -870,11 +882,13 @@ def deploy_raiden_arguments(
     return arguments
 
 
-@patch.object(ContractDeployer, "deploy_raiden_contracts")
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_raiden")
+@patch.object(ContractDeployer, "deploy_raiden_contracts")
+@patch.object(ContractDeployer, "_adjust_chain_settings")
 @pytest.mark.parametrize("contracts_version", [None, ALDERAAN_VERSION])
 @pytest.mark.parametrize("reuse_secret_registry", [False, True])
 def test_deploy_raiden(
+    mock_adjust_chain_settings: MagicMock,
     mock_deploy: MagicMock,
     mock_verify: MagicMock,
     contracts_version: Optional[str],
@@ -895,13 +909,16 @@ def test_deploy_raiden(
         )
         assert result.exception is None
         assert result.exit_code == 0
+        mock_adjust_chain_settings.assert_called_once()
         mock_deploy.assert_called_once()
         mock_verify.assert_called_once()
 
 
 @patch.object(ContractDeployer, "register_token_network")
+@patch.object(ContractDeployer, "_adjust_chain_settings")
 def test_register_script(
-    mock_deploy: MagicMock,
+    mock_adjust_chain_settings: MagicMock,
+    mock_register: MagicMock,
     deployed_raiden_info: DeployedContracts,
     privkey_file: IO,
 ) -> None:
@@ -935,12 +952,18 @@ def test_register_script(
                 catch_exceptions=False,
             )
             assert result.exit_code == 0
-            mock_deploy.assert_called_once()
+            mock_adjust_chain_settings.assert_called_once()
+            mock_register.assert_called_once()
             add_tn_info.assert_called_once()
 
 
 @patch.object(ContractDeployer, "register_token_network")
-def test_register_script_without_token_network(mock_deploy: MagicMock, privkey_file: IO) -> None:
+@patch.object(ContractDeployer, "_adjust_chain_settings")
+def test_register_script_without_token_network(
+    mock_adjust_chain_settings: MagicMock,
+    mock_register: MagicMock,
+    privkey_file: IO,
+) -> None:
     """Calling deploy raiden command"""
     with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
@@ -968,13 +991,18 @@ def test_register_script_without_token_network(mock_deploy: MagicMock, privkey_f
             "No TokenNetworkRegistry was specified. "
             "Add --token-network-registry-address <address>.",
         )
-        mock_deploy.assert_not_called()
+        mock_adjust_chain_settings.assert_called_once()
+        mock_register.assert_not_called()
 
 
-@patch.object(ContractDeployer, "deploy_raiden_contracts")
 @patch.object(ContractDeployer, "verify_deployment_data")
+@patch.object(ContractDeployer, "deploy_raiden_contracts")
+@patch.object(ContractDeployer, "_adjust_chain_settings")
 def test_deploy_raiden_save_info_false(
-    mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
+    mock_adjust_chain_settings: MagicMock,
+    mock_deploy: MagicMock,
+    mock_verify: MagicMock,
+    privkey_file: IO,
 ) -> None:
     """Calling deploy raiden command with --save_info False"""
     with patch.object(Eth, "get_balance", return_value=1):
@@ -990,6 +1018,7 @@ def test_deploy_raiden_save_info_false(
         )
         assert result.exception is None
         assert result.exit_code == 0
+        mock_adjust_chain_settings.assert_called_once()
         mock_deploy.assert_called_once()
         mock_verify.assert_called_once()
 
@@ -1038,9 +1067,15 @@ def deploy_services_arguments(
     return arguments
 
 
-@patch.object(ContractDeployer, "deploy_service_contracts")
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_services")
-def test_deploy_services(mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO) -> None:
+@patch.object(ContractDeployer, "deploy_service_contracts")
+@patch.object(ContractDeployer, "_adjust_chain_settings")
+def test_deploy_services(
+    mock_adjust_chain_settings: MagicMock,
+    mock_deploy: MagicMock,
+    mock_verify: MagicMock,
+    privkey_file: IO,
+) -> None:
     """Calling deploy raiden command"""
     with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
@@ -1055,6 +1090,7 @@ def test_deploy_services(mock_deploy: MagicMock, mock_verify: MagicMock, privkey
         )
         assert result.exception is None
         assert result.exit_code == 0
+        mock_adjust_chain_settings.assert_called_once()
         mock_deploy.assert_called_once()
         mock_verify.assert_called_once()
 
@@ -1077,10 +1113,14 @@ def test_deploy_old_services(privkey_file: IO) -> None:
         assert result.exit_code == 2
 
 
-@patch.object(ContractDeployer, "deploy_service_contracts")
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_services")
+@patch.object(ContractDeployer, "deploy_service_contracts")
+@patch.object(ContractDeployer, "_adjust_chain_settings")
 def test_deploy_services_with_controller(
-    mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
+    mock_adjust_chain_settings: MagicMock,
+    mock_deploy: MagicMock,
+    mock_verify: MagicMock,
+    privkey_file: IO,
 ) -> None:
     """Calling deploy raiden command"""
     with patch.object(Eth, "get_balance", return_value=1):
@@ -1096,14 +1136,19 @@ def test_deploy_services_with_controller(
         )
         assert result.exception is None
         assert result.exit_code == 0
+        mock_adjust_chain_settings.assert_called_once()
         mock_deploy.assert_called_once()
         mock_verify.assert_called_once()
 
 
-@patch.object(ContractDeployer, "deploy_service_contracts")
 @patch.object(ContractDeployer, "verify_service_contracts_deployment_data")
+@patch.object(ContractDeployer, "deploy_service_contracts")
+@patch.object(ContractDeployer, "_adjust_chain_settings")
 def test_deploy_services_save_info_false(
-    mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
+    mock_adjust_chain_settings: MagicMock,
+    mock_deploy: MagicMock,
+    mock_verify: MagicMock,
+    privkey_file: IO,
 ) -> None:
     """Calling deploy raiden command with --save_info False"""
     with patch.object(Eth, "get_balance", return_value=1):
@@ -1119,6 +1164,7 @@ def test_deploy_services_save_info_false(
         )
         assert result.exception is None
         assert result.exit_code == 0
+        mock_adjust_chain_settings.assert_called_once()
         mock_deploy.assert_called_once()
         mock_verify.assert_called_once()
 
@@ -1186,6 +1232,7 @@ def test_user_deposit_deployment_with_wrong_one_to_n_address() -> None:
             constructor_arguments=user_deposit_constructor_arguments,
             token_address=token_addr,
             user_deposit_whole_balance_limit=UINT256_MAX,
+            user_deposit_withdraw_timeout=WITHDRAW_TIMEOUT,
             one_to_n_address=wrong_one_to_n_address,
             monitoring_service_address=HexAddress(
                 HexStr("0xb7765972d78B6C97bB0a5a6b7529DC1fb64aA287")
