@@ -10,13 +10,11 @@ from raiden_contracts.constants import (
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     EVENT_DEPRECATION_SWITCH,
     EVENT_TOKEN_NETWORK_CREATED,
-    TEST_SETTLE_TIMEOUT_MAX,
-    TEST_SETTLE_TIMEOUT_MIN,
+    TEST_SETTLE_TIMEOUT,
 )
 from raiden_contracts.contract_manager import ContractManager
 from raiden_contracts.tests.fixtures.channel import call_settle
 from raiden_contracts.tests.utils import ChannelValues, LockedAmounts, call_and_transact
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.pending_transfers import (
     get_pending_transfers_tree_with_generated_lists,
 )
@@ -46,9 +44,8 @@ def test_controller(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
         controller,
         _secret_registry_address=secret_registry_contract.address,
-        _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
-        _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
         _max_token_networks=1,
+        _settle_timeout=TEST_SETTLE_TIMEOUT,
     )
 
     # Make sure deployer is controller
@@ -162,6 +159,8 @@ def test_deprecation_switch_settle(
     create_channel: Callable,
     channel_deposit: Callable,
     close_and_update_channel: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Channel close and settlement still work after the depracation switch is turned on"""
     controller = token_network.functions.controller().call()
@@ -217,7 +216,8 @@ def test_deprecation_switch_settle(
 
     # We need to make sure we can still close, settle & unlock the channels
     close_and_update_channel(channel_identifier, A, vals_A, B, vals_B)
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
