@@ -11,6 +11,7 @@ from web3.contract import Contract
 from raiden_contracts.constants import (
     CONTRACT_MONITORING_SERVICE,
     LOCKSROOT_OF_NO_LOCKS,
+    TEST_SETTLE_TIMEOUT,
     MessageTypeId,
     MonitoringServiceEvent,
 )
@@ -20,7 +21,6 @@ from raiden_contracts.tests.utils import (
     SERVICE_DEPOSIT,
     call_and_transact,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.proofs import sign_reward_proof
 from raiden_contracts.utils.type_aliases import TokenAmount
 
@@ -105,13 +105,15 @@ def setup_monitor_data(
         )
 
         # calculate when this MS is allowed to monitor
-        first_allowed = monitoring_service_contract.functions.firstBlockAllowedToMonitorChannel(
-            token_network=token_network.address,
-            channel_identifier=channel_identifier,
-            closing_participant=A,
-            non_closing_participant=B,
-            monitoring_service_address=ms_address,
-        ).call()
+        first_allowed = (
+            monitoring_service_contract.functions.firstTimestampAllowedToMonitorChannel(
+                token_network=token_network.address,
+                channel_identifier=channel_identifier,
+                closing_participant=A,
+                non_closing_participant=B,
+                monitoring_service_address=ms_address,
+            ).call()
+        )
 
         # return args for `monitor` function
         return {
@@ -147,14 +149,15 @@ def test_claimReward_with_settle_call(
     event_handler: Callable,
     monitor_data: Dict,
     ms_address: HexAddress,
-    web3: Web3,
     with_settle: bool,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     A, B = monitor_data["participants"]
     channel_identifier = monitor_data["channel_identifier"]
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
+    time_travel(monitor_data["first_allowed"] + 1)
 
     # MS updates closed channel on behalf of B
     txn_hash = call_and_transact(
@@ -177,7 +180,7 @@ def test_claimReward_with_settle_call(
         ).call({"from": ms_address})
 
     # Settle channel after settle_timeout elapsed
-    mine_blocks(web3, 4)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT)
     if with_settle:
         call_and_transact(
             token_network.functions.settleChannel(
@@ -227,7 +230,8 @@ def test_monitor(
     monitor_data: Dict,
     ms_address: HexAddress,
     event_handler: Callable,
-    web3: Web3,
+    get_block_timestamp: Callable,
+    time_travel: Callable,
 ) -> None:
     A, B = monitor_data["participants"]
 
@@ -251,7 +255,7 @@ def test_monitor(
 
     # monitoring too early must fail
     with pytest.raises(TransactionFailed, match="not allowed to monitor"):
-        assert web3.eth.block_number < monitor_data["first_allowed"]
+        assert get_block_timestamp() < monitor_data["first_allowed"]
         call_and_transact(
             monitoring_service_external.functions.monitor(
                 A,
@@ -266,7 +270,7 @@ def test_monitor(
         )
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
+    time_travel(monitor_data["first_allowed"] + 1)
 
     # successful monitor call
     txn_hash = call_and_transact(
@@ -303,12 +307,12 @@ def test_monitor_by_unregistered_service(
     monitoring_service_external: Contract,
     monitor_data: Dict,
     ms_address: HexAddress,
-    web3: Web3,
+    time_travel: Callable,
 ) -> None:
     A, B = monitor_data["participants"]
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
+    time_travel(monitor_data["first_allowed"] + 1)
 
     # only registered service providers may call `monitor`
     with pytest.raises(TransactionFailed, match="service not registered"):
@@ -342,12 +346,12 @@ def test_monitor_on_wrong_token_network_registry(
     monitoring_service_external: Contract,
     monitor_data: Dict,
     ms_address: HexAddress,
-    web3: Web3,
+    time_travel: Callable,
 ) -> None:
     A, B = monitor_data["participants"]
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
+    time_travel(monitor_data["first_allowed"] + 1)
 
     # monitor() call fails because the TokenNetwork is not registered on the
     # supposed TokenNetworkRegistry
@@ -406,14 +410,14 @@ def test_updateReward(
     assert monitoring_service_internals.functions.rewardNonce(reward_identifier).call() == 3
 
 
-def test_pureFirstAllowedBlock(monitoring_service_external: Contract) -> None:
+def test_pureFirstAllowedTimestamp(monitoring_service_external: Contract) -> None:
     def call(addresses: List[int], closed_at_block: int = 1000, settle_timeout: int = 100) -> int:
-        first_allowed = monitoring_service_external.functions.firstBlockAllowedToMonitor(
-            closed_at_block=closed_at_block,
-            settle_timeout=settle_timeout,
-            participant1=to_checksum_address("0x%040x" % addresses[0]),
-            participant2=to_checksum_address("0x%040x" % addresses[1]),
-            monitoring_service_address=to_checksum_address("0x%040x" % addresses[2]),
+        first_allowed = monitoring_service_external.functions.firstTimestampAllowedToMonitor(
+            closed_at_block,
+            settle_timeout,
+            to_checksum_address("0x%040x" % addresses[0]),
+            to_checksum_address("0x%040x" % addresses[1]),
+            to_checksum_address("0x%040x" % addresses[2]),
         ).call()
         assert closed_at_block < first_allowed <= closed_at_block + settle_timeout
         return first_allowed
@@ -431,17 +435,6 @@ def test_pureFirstAllowedBlock(monitoring_service_external: Contract) -> None:
     MAX_ADDRESS = 256**20 - 1
     assert call([MAX_ADDRESS] * 3) == 1000 + 30 + (3 * MAX_ADDRESS) % 50
 
-    # The highest settle_timeout does not cause overflows
-    MAX_SETTLE_TIMEOUT = (2**256 - 1) // 100 - 1
-    assert call([1, 2, 3], settle_timeout=MAX_SETTLE_TIMEOUT) == 1000 + (
-        MAX_SETTLE_TIMEOUT * 30
-    ) // 100 + (1 + 2 + 3)
-
-    # Extreme settle_timeout that would cause overflows will make the
-    # transaction fail instead of giving the wrong result
-    with pytest.raises(TransactionFailed, match="maliciously big settle timeout"):
-        assert call([1, 2, 3], settle_timeout=MAX_SETTLE_TIMEOUT + 1)
-
 
 def test_recoverAddressFromRewardProof(
     monitor_data_internal: Dict, token_network: Contract, monitoring_service_internals: Contract
