@@ -1,20 +1,17 @@
 from typing import Callable
 
-import pytest
-from eth_tester.exceptions import TransactionFailed
-from web3 import Web3
 from web3.contract import Contract
 
-from raiden_contracts.constants import TEST_SETTLE_TIMEOUT_MAX, TEST_SETTLE_TIMEOUT_MIN
+from raiden_contracts.constants import TEST_SETTLE_TIMEOUT, ChannelState
 from raiden_contracts.tests.utils import LOCKSROOT_OF_NO_LOCKS, call_and_transact, fake_bytes
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 
 
 def test_settle_timeout_inrange(
     token_network: Contract,
     get_accounts: Callable,
-    web3: Web3,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """The TokenNetwork constructor must enforce that settle timeout is in
     the valid range.
@@ -24,22 +21,13 @@ def test_settle_timeout_inrange(
     """
     (A, B) = get_accounts(2)
 
-    small_settle_timeout = TEST_SETTLE_TIMEOUT_MIN - 1
-    large_settle_timeout = TEST_SETTLE_TIMEOUT_MAX + 1
-
-    with pytest.raises(TransactionFailed, match="TN: settle timeout < min"):
-        token_network.functions.openChannel(A, B, small_settle_timeout).call()
-
-    with pytest.raises(TransactionFailed, match="TN: settle timeout > max"):
-        token_network.functions.openChannel(A, B, large_settle_timeout).call()
-
-    call_and_transact(token_network.functions.openChannel(A, B, TEST_SETTLE_TIMEOUT_MIN))
+    call_and_transact(token_network.functions.openChannel(A, B))
     channel_identifier = token_network.functions.getChannelIdentifier(A, B).call()
-    (settle_block_number, _) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    settle_timeout = token_network.functions.settle_timeout().call()
+    settleable_after = token_network.functions.settleable_after(channel_identifier).call()
 
-    assert settle_block_number == TEST_SETTLE_TIMEOUT_MIN
+    assert settle_timeout == TEST_SETTLE_TIMEOUT
+    assert settleable_after == 0
 
     closing_sig = create_close_signature_for_no_balance_proof(A, channel_identifier)
     call_and_transact(
@@ -55,7 +43,9 @@ def test_settle_timeout_inrange(
         ),
         {"from": A},
     )
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+
+    time_travel(get_block_timestamp() + settle_timeout + 2)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier,
@@ -70,10 +60,10 @@ def test_settle_timeout_inrange(
         ),
         {"from": A},
     )
-    call_and_transact(token_network.functions.openChannel(A, B, TEST_SETTLE_TIMEOUT_MAX))
+    call_and_transact(token_network.functions.openChannel(A, B))
     channel_identifier = token_network.functions.getChannelIdentifier(A, B).call()
-    (settle_block_number, _) = token_network.functions.getChannelInfo(
-        channel_identifier, A, B
-    ).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+    settleable_after = token_network.functions.settleable_after(channel_identifier).call()
 
-    assert settle_block_number == TEST_SETTLE_TIMEOUT_MAX
+    assert state == ChannelState.OPENED
+    assert settleable_after == 0
